EscDshot

Struct EscDshot 

pub struct EscDshot { /* private fields */ }

Implementations

Source

impl EscDshot

pub const DEFAULT_CPU_FREQUENCY: u32 = 150_000_000

pub const fn new(protocol: DshotSpeed) -> Self

pub const fn with_cpu_frequency(self, cpu_frequency: u32) -> Self

Set the cpu_frequency of a newly constructed EscDshot.

Source

impl EscDshot

pub const fn nano_seconds_to_cycles(self, nano_seconds: u32) -> u16

pub const fn set_cpu_frequency(&mut self, cpu_frequency: u32)

pub const fn set_protocol(&mut self, protocol: DshotSpeed)

pub fn duty_cycles_u16(&self, frame: u16) -> [u16; 17]

Returns an array of duty cycles for use in PWM DMA.

The array an extra element set to zero to ensure that PWM output gets pulled low at the end of the sequence.

pub fn duty_cycles_u32( &self, frame: u16, use_high_order_bits: bool, ) -> [u32; 17]

Returns an array of duty cycles for use in PWM DMA.

The array an extra element set to zero to ensure that PWM output gets pulled low at the end of the sequence.